@@ -21,7 +21,6 @@
 #include "kcalutils_debug.h"
 
 #include <QLocale>
-#include <QDate>
 
 #include <grantlee/safestring.h>
 
@@ -68,9 +67,7 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, c
                 break;
             }
             // fall-through
-#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
             Q_FALLTHROUGH();
-#endif
         default:
             qCWarning(KCALUTILS_LOG) << "Unknown type" << iter->typeName() << "(" << iter->type() << ")";
             break;
